@@ -134,6 +134,7 @@ class extensionModel extends model
      * @param  string $extenstion
      * @access public
      * @return object
+     * @param string $extension
      */
     public function getCondition($extension)
     {
@@ -723,7 +724,7 @@ class extensionModel extends model
                 {
                     $commandTips[] = PHP_OS == 'Linux' ? "sudo rm -fr $appRoot$dir" : "rmdir $appRoot$dir /s /q";
                 }
-                elseif(!@rmdir($path))
+                elseif(!$this->classFile->removeDir($path))
                 {
                     $commandTips[] = PHP_OS == 'Linux' ? "sudo rm -fr $appRoot$dir" : "rmdir $appRoot$dir /s /q";
                 }
