@@ -223,8 +223,8 @@ class productplanModel extends model
 
         $plans = $this->dao->select('t1.id,t1.title,t1.parent,t1.begin,t1.end,t2.type as productType,t1.branch')->from(TABLE_PRODUCTPLAN)->alias('t1')
             ->leftJoin(TABLE_PRODUCT)->alias('t2')->on('t2.id=t1.product')
-            ->where('t1.product')->in($productIdList)
-            ->andWhere('t1.deleted')->eq(0)
+            ->where('t1.deleted')->eq('0')
+            ->beginIF($productIdList)->andWhere('t1.product')->in($productIdList)->fi()
             ->beginIF(!empty($branchQuery))->andWhere($branchQuery)->fi()
             ->beginIF(strpos($param, 'unexpired') !== false)->andWhere('t1.end')->ge(date('Y-m-d'))->fi()
             ->beginIF(strpos($param, 'noclosed')  !== false)->andWhere('t1.status')->ne('closed')->fi()
@@ -889,7 +889,6 @@ class productplanModel extends model
             $this->story->setStage($storyID);
         }
 
-        $this->productplanTao->syncLinkedStories($planID, $storyIdList, false);
         $this->action->create('productplan', $planID, 'linkstory', '', implode(',', $storyIdList));
 
         return !dao::isError();
@@ -1093,51 +1092,38 @@ class productplanModel extends model
      */
     public static function isClickable($plan, $action)
     {
-        global $app;
+        $action = strtolower($action);
+
         switch($action)
         {
-            case 'create' :
-                if($plan->parent > 0 || strpos('done,closed', $plan->status) !== false) return false;
-                break;
-            case 'start' :
-                if($plan->status != 'wait' || $plan->isParent) return false;
-                break;
-            case 'finish' :
-                if($plan->status != 'doing' || $plan->isParent) return false;
-                break;
-            case 'close' :
-                if($plan->status == 'closed' || $plan->isParent) return false;
-                break;
-            case 'activate' :
-                if($plan->status == 'wait' || $plan->status == 'doing' || $plan->isParent) return false;
-                break;
-            case 'delete' :
-                if($plan->isParent) return false;
-                break;
-            case 'createExecution' :
+            case 'create':
+                return $plan->parent <= 0 && $plan->status != 'done' && $plan->status != 'closed';
+            case 'start':
+                return !$plan->isParent && $plan->status == 'wait';
+            case 'finish':
+                return !$plan->isParent && $plan->status == 'doing';
+            case 'close':
+                return !$plan->isParent && $plan->status != 'closed';
+            case 'activate':
+                return !$plan->isParent && $plan->status != 'wait' && $plan->status != 'doing';
+            case 'delete':
+            case 'linkstory':
+            case 'linkbug':
+                return !$plan->isParent;
+            case 'createexecution':
                 if($plan->isParent || $plan->expired || in_array($plan->status, array('done', 'closed')) || !common::hasPriv('execution', 'create', $plan)) return false;
 
-                $product          = $app->control->loadModel('product')->getByID($plan->product);
-                $branchList       = $app->control->loadModel('branch')->getList($plan->product, 0, 'all');
-                $branchStatusList = array();
-                foreach($branchList as $productBranch) $branchStatusList[$productBranch->id] = $productBranch->status;
-
-                if($product->type != 'normal')
+                static $cache = null;
+                if(is_null($cache))
                 {
-                    $branchStatus = isset($branchStatusList[$plan->branch]) ? $branchStatusList[$plan->branch] : '';
-                    if($branchStatus == 'closed') return false;
+                    global $app;
+                    $cache['products'] = $app->dao->select('id')->from(TABLE_PRODUCT)->where('deleted')->eq('0')->andWhere('type')->ne('normal')->fetchPairs();
+                    $cache['branches'] = $app->dao->select('id')->from(TABLE_BRANCH)->where('deleted')->eq('0')->andWhere('status')->eq('closed')->fetchPairs();
                 }
-
-                break;
-            case 'linkStory' :
-                if($plan->isParent) return false;
-                break;
-            case 'linkBug' :
-                if($plan->isParent) return false;
-                break;
+                return !isset($cache['products'][$plan->product]) || !isset($cache['branches'][$plan->branch]);
+            default:
+                return true;
         }
-
-        return true;
     }
 
     /**
